"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decorate = decorate;
const index_js_1 = require("../helpers/index.js");
const meta_js_1 = require("./meta.js");
// core implementation of this rule raises false positives for generators
function decorate(rule) {
    return (0, index_js_1.interceptReport)({
        ...rule,
        meta: (0, index_js_1.generateMeta)(meta_js_1.meta, rule.meta),
    }, reportExempting(isReferencedInsideGenerators));
}
function reportExempting(exemptionCondition) {
    return (context, reportDescriptor) => {
        if ('node' in reportDescriptor) {
            const node = reportDescriptor['node'];
            if (!exemptionCondition(context, node)) {
                context.report(reportDescriptor);
            }
        }
    };
}
function isReferencedInsideGenerators(context, node) {
    const variable = (0, index_js_1.getVariableFromName)(context, node.name, node);
    if (variable) {
        for (const reference of variable.references) {
            let scope = reference.from;
            while (scope !== null && !scope.variables.includes(variable)) {
                if (isGenerator(scope.block)) {
                    return true;
                }
                scope = scope.upper;
            }
        }
    }
    return false;
    function isGenerator(node) {
        return ((node.type === 'FunctionDeclaration' || node.type === 'FunctionExpression') &&
            node.generator === true);
    }
}
