"use strict";
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2024 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
// https://sonarsource.github.io/rspec/#/rspec/S6957/javascript
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.rule = void 0;
const eslint_plugin_react_1 = __importDefault(require("eslint-plugin-react"));
const { rules } = eslint_plugin_react_1.default;
const index_js_1 = require("../helpers/index.js");
const meta_js_1 = require("./meta.js");
const posix_1 = require("path/posix");
const reactNoDeprecated = rules['no-deprecated'];
const messages = {
    deprecated: '{{oldMethod}} is deprecated since React {{version}}{{newMethod}}',
};
exports.rule = {
    meta: (0, index_js_1.generateMeta)(meta_js_1.meta, { messages, schema: meta_js_1.schema }),
    create(context) {
        function getVersionFromOptions() {
            return context.options[0]?.['react-version'];
        }
        function getVersionFromPackageJson() {
            for (const packageJson of (0, index_js_1.getManifests)((0, posix_1.dirname)((0, index_js_1.toUnixPath)(context.filename)), context.cwd)) {
                if (packageJson.dependencies?.react) {
                    return packageJson.dependencies.react;
                }
                if (packageJson.devDependencies?.react) {
                    return packageJson.devDependencies.react;
                }
            }
            return null;
        }
        const reactVersion = getVersionFromOptions() || getVersionFromPackageJson();
        const patchedContext = reactVersion
            ? Object.create(context, {
                settings: {
                    value: { react: { version: reactVersion } },
                    writable: false,
                },
            })
            : context;
        return reactNoDeprecated.create(patchedContext);
    },
};
